"""
Codigos de errores:


100 - es humano
101 - fallo la comunicacion con google
102 - accion incorrecta
103 - no alcanzo el umbral esperadp

"""

import http.client, urllib.parse
import json
import logging

logger = logging.getLogger(__name__)

headers = {
    "Content-type": "application/x-www-form-urlencoded",
    "Accept": "text/plain"
}


def request(payload):
    params = urllib.parse.urlencode(payload)
    conn = http.client.HTTPSConnection("www.google.com")
    conn.request('POST', '/recaptcha/api/siteverify', params, headers)
    return json.loads(conn.getresponse().read())


def is_a_human(secret_key, response_token, action=None, threshold=0.5):
    payload = {
        'secret': secret_key,
        'response': response_token
    }
    response = request(payload)
    if not response['success']:
        logger.warning("Failed comunication")
        return False, 101
    elif response["score"] >= threshold:
        if action and response.get('action', None):
            if action != response['action']:
                logger.warning("Bad action name. action send: %s , action expected: %s" % (action, response['action']))
                return False, 102
        logger.info("Is human")
        return True, 100
    else:
        logger.warning("Threshold failed, get: %s , expected < %s" % (response['score'], threshold))
        return False, 103


def crecaptcha(secret_key, response_token, action=None, threshold=0.5):
    ok, _ = is_a_human(secret_key, response_token, action, threshold)
    return ok



from crecatpcha.crecaptcha import is_a_human
import logging
from django.conf import settings
from django.http import HttpResponseForbidden

logger = logging.getLogger(__name__)

SECRET_KEY = settings.CRECAPTCHA_SECRET_KEY
try:
    KEY_NAME = settings.CRECAPTCHA_KEY_NAME
except:
    KEY_NAME = 'recaptcha_token'


def crecaptcha(action=None,
               on_error_function=None,
               args_on_error=[],
               kwargs_on_error={},
               threshold=0.5):
    def do_challenge(func):
        def check_captcha(*args, **kwargs):
            request = args[0]
            ok, code = is_a_human(SECRET_KEY, request.POST[KEY_NAME], action=action, threshold=threshold)
            if ok:
                return func(*args, **kwargs)
            else:
                if not on_error_function:
                    raise HttpResponseForbidden
                kwargs_on_error['data'] = {'code': code, 'info': 'cRecaptcha error'}
                return on_error_function(*args, *args_on_error, **kwargs_on_error)

        return check_captcha

    return do_challenge



from setuptools import setup

setup(
    name='crecaptcha',
    version='0.1.31',
    author='Steib Cristian',
    author_email='cristiansteib@gmail.com',
    packages=['crecatpcha'],
    url='https://github.com/cristiansteib/crecaptcha/',
    license='LICENSE.txt',
    description='reCatpcha api v3.0 - with django support',
    long_description=open('README.md').read(),
    long_description_content_type="text/markdown",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "Framework :: Django",
        "Framework :: Flask",
        "License :: OSI Approved :: Apache Software License",
        "Topic :: Security"
    ],
)
